<?php
/** Simplified Gan script (赣语（简体）‎)
 *
 * To improve a translation please visit https://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 */

$fallback = 'zh-hans';

$namespaceNames = [
	NS_TALK             => '谈詑',
	NS_USER_TALK        => '用户谈詑',
	NS_PROJECT_TALK     => '$1谈詑',
	NS_FILE_TALK        => '文件谈詑',
	NS_MEDIAWIKI_TALK   => 'MediaWiki谈詑',
	NS_TEMPLATE_TALK    => '模板谈詑',
	NS_HELP_TALK        => '帮助谈詑',
	NS_CATEGORY_TALK    => '分类谈詑',
];

